a data.frame, the raw output from EPGMTime (when raw.time.output=TRUE).
WaterColumn.Thresholds
a list of three water column total phosphorus thresholds to evaluate time output.
Soil.Thresholds
a list of three soil total phosphorus thresholds to evaluate time output.
cattail.Thresholds
a list of three cattail density thresholds to evaluate time output.
plot.exceed
If TRUE base plot will be generate with water column, soil and cattail area exceeded plots.
raw.area.output
If TRUE a data.frame will be printed with all area exceedances calculated for each time step.Default is set to FALSE.
results.area.table
If TRUE a summary results table will be printed in the console. Default is set to TRUE.
Value
This function computes and plots the distance profile along the gradient based on input values
Details
As described in the original documentation, the model is designed to simulate marsh enrichment (responses to increasing P load), not recovery (responses to decreasing in load).